#/*------------------------------------------------------------------------------
#--  This file is a part of the libuc, microcontroler library
#--  Copyright (C) 2011, Alexis Jeandet
#--
#--  This program is free software; you can redistribute it and/or modify
#--  it under the terms of the GNU General Public License as published by
#--  the Free Software Foundation; either version 3 of the License, or
#--  (at your option) any later version.
#--
#--  This program is distributed in the hope that it will be useful,
#--  but WITHOUT ANY WARRANTY; without even the implied warranty of
#--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#--  GNU General Public License for more details.
#--
#--  You should have received a copy of the GNU General Public License
#--  along with this program; if not, write to the Free Software
#--  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#-------------------------------------------------------------------------------
#--                 Author : Alexis Jeandet
#--                   Mail : alexis.jeandet@gmail.com
#-------------------------------------------------------------------------------*/

#---------------------------------------------------------------------------------
#       GCC EXECUTABLES
#---------------------------------------------------------------------------------
LIBUC_PREFIX = arm-none-eabi-
LIBUC_CC  = $(LIBUC_PREFIX)gcc
LIBUC_CXX = $(LIBUC_PREFIX)g++
LIBUC_AR  = $(LIBUC_PREFIX)ar
LIBUC_RANLIB  = $(LIBUC_PREFIX)ranlib
LIBUC_AS  = $(LIBUC_PREFIX)as
LIBUC_LD  = $(LIBUC_PREFIX)ld
LIBUC_SIZE = $(LIBUC_PREFIX)size
LIBUC_STRIP = $(LIBUC_PREFIX)strip -s
LIBUC_READELF = $(LIBUC_PREFIX)readelf
LIBUC_OBJCOPY=$(LIBUC_PREFIX)objcopy
LIBUC_OBJDUMP=$(LIBUC_PREFIX)objdump



#---------------------------------------------------------------------------------
#       GCC FLAGS
#---------------------------------------------------------------------------------
LIBUC_FMCU              = -mcpu=cortex-m3
LIBUC_CFLAGS            = $(LIBUC_FMCU)
LIBUC_CFLAGS            = --std=gnu99 -fgnu89-inline -mcpu=cortex-m3  -mthumb
LIBUC_CFLAGS   		+= -ffunction-sections -fdata-sections
LIBUC_LDFLAGS  		= --gc-sections
LIBUC_ODFLAGS  		= -x --syms
LIBUC_CPFLAGS		= 
LIBUC_CFLAGS_WARN_ON	= -Wall
LIBUC_CFLAGS_WARN_OFF	= -w
LIBUC_CFLAGS_RELEASE	= -O2
LIBUC_CFLAGS_DEBUG	= -g
LIBUC_CFLAGS_RELEASE_WITH_DEBUGINFO += -O2 -g
LIBUC_CFLAGS_STATIC_LIB	= -fPIC
LIBUC_CFLAGS_SOFT_FPU	= -msoft-float
LIBUC_CFLAGS_HARD_FPU	=

LIBUC_CXXFLAGS          = $(LIBUC_FMCU)
LIBUC_CXXFLAGS         += -g -gdwarf-2
LIBUC_CXXFLAGS         += -Wextra -Wundef -Wcast-align -mthumb -msoft-float
LIBUC_CXXFLAGS_WARN_ON	= -Wall
LIBUC_CXXFLAGS_WARN_OFF	= -w
LIBUC_CXXFLAGS_RELEASE	= -O2
LIBUC_CXXFLAGS_DEBUG	= -g
LIBUC_CXXFLAGS_RELEASE_WITH_DEBUGINFO += -O2 -g
LIBUC_CXXFLAGS_STATIC_LIB = -fPIC
LIBUC_CXXFLAGS_SOFT_FPU	= -msoft-float
LIBUC_CXXFLAGS_HARD_FPU	=

#---------------------------------------------------------------------------------
#       LIBRARY DEFINITIONS
#---------------------------------------------------------------------------------

LIBUC_LIBS_DIR              = $(LIBUC)/lib/bin/$(ARCH)
LIBUC_INC_DIR              = $(LIBUC)/lib/includes
include $(LIBUC)/rules/common/libsrules.mk

#---------------------------------------------------------------------------------
#       BOARD SUPORT PACKAGES
#---------------------------------------------------------------------------------
LIBUC_BSP_DIR=$(LIBUC)/bsp
LIBUC_BSP_BIN_DIR= $(LIBUC_BSP_DIR)/bin
LIBUC_BSP_INC_DIR= $(LIBUC_BSP_DIR)/includes
LIBUC_BSP = -L $(LIBUC_BSP_BIN_DIR)/$(BSP) -static -lbsp
LIBUC_BSP_INC = -I $(LIBUC_BSP_INC_DIR)/$(BSP)
#---------------------------------------------------------------------------------
#       DEVICE SPECIAL FILES
#---------------------------------------------------------------------------------
LINKER_SCRIPT = $(ARCHFOLDER)/LPC17xx.ld
LPC17XX_INCDIR = $(ARCHFOLDER)


INCLUDES = $(LPC17XX_INCDIR) -I $(LIBUC_INC_DIR) $(LIBUC_INCLUDES) $(LIBUC_BSP_INC)
CFLAGS = $(LIBUC_CFLAGS)

SOURCES += syscalls.c 
SOURCES += startup_LPC17xx.s

APPOBJECTFILES += $(OBJDIR)/syscalls.o 
APPOBJECTFILES += $(OBJDIR)/startup_LPC17xx.o
#---------------------------------------------------------------------------------
#       RULES
#---------------------------------------------------------------------------------

first: all

$(OBJDIR)/syscalls.o: $(ARCHFOLDER)/syscalls.c $(OBJDIR) 
	$(LIBUC_CC) -O3 -I $(INCLUDES) -c $(CFLAGS) $< -o $@


$(OBJDIR)/startup_LPC17xx.o: $(ARCHFOLDER)/startup_LPC17xx.s $(OBJDIR) 
	$(LIBUC_CC) -O3 -I $(INCLUDES) -c $(CFLAGS) $< -o $@


